
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */


#include "config.h"

#include "dzl-enums.h"

#include "app/dzl-application-window.h"
#include "files/dzl-file-transfer.h"
#include "tree/dzl-tree-types.h"
/* enumerations from "dzl-application-window.h" */
GType
dzl_titlebar_animation_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { DZL_TITLEBAR_ANIMATION_HIDDEN, "DZL_TITLEBAR_ANIMATION_HIDDEN", "hidden" },
            { DZL_TITLEBAR_ANIMATION_SHOWING, "DZL_TITLEBAR_ANIMATION_SHOWING", "showing" },
            { DZL_TITLEBAR_ANIMATION_SHOWN, "DZL_TITLEBAR_ANIMATION_SHOWN", "shown" },
            { DZL_TITLEBAR_ANIMATION_HIDING, "DZL_TITLEBAR_ANIMATION_HIDING", "hiding" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("DzlTitlebarAnimation"), values);
    }
    return etype;
}
/* enumerations from "dzl-file-transfer.h" */
GType
dzl_file_transfer_flags_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GFlagsValue values[] = {
            { DZL_FILE_TRANSFER_FLAGS_NONE, "DZL_FILE_TRANSFER_FLAGS_NONE", "none" },
            { DZL_FILE_TRANSFER_FLAGS_MOVE, "DZL_FILE_TRANSFER_FLAGS_MOVE", "move" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static (g_intern_static_string ("DzlFileTransferFlags"), values);
    }
    return etype;
}
/* enumerations from "dzl-tree-types.h" */
GType
dzl_tree_drop_position_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { DZL_TREE_DROP_INTO, "DZL_TREE_DROP_INTO", "into" },
            { DZL_TREE_DROP_BEFORE, "DZL_TREE_DROP_BEFORE", "before" },
            { DZL_TREE_DROP_AFTER, "DZL_TREE_DROP_AFTER", "after" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("DzlTreeDropPosition"), values);
    }
    return etype;
}


/* Generated data ends here */

